<?php
/**
 * Components functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Fotografie Pro
 */

if ( ! function_exists( 'fotografie_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the aftercomponentsetup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function fotografie_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on components, use a find and replace
		 * to change 'fotografie-pro' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'fotografie-pro', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		set_post_thumbnail_size( 1148, 574, true );

		add_image_size( 'fotografie-featured', 533, 533, true );

		add_image_size( 'fotografie-featured-fluid', 640, 640, true );

		add_image_size( 'fotografie-slider', 1920, 1080, true );

		add_image_size( 'fotografie-hero-image', 864, 864, true );

		add_image_size( 'fotografie-header-image', 1920, 689, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1'      => esc_html__( 'Header', 'fotografie-pro' ),
			'social-menu' => esc_html__( 'Social Menu', 'fotografie-pro' ),
		) );

		/**
		 * Add support for core custom logo.
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 200,
			'width'       => 200,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		/*
		 * Enable support for Post Formats.
		 * See https://developer.wordpress.org/themes/functionality/post-formats/
		 */
		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'quote',
			'link',
		) );

		/*
		 * This theme styles the visual editor to resemble the theme style,
		 * specifically font, colors, icons, and column width.
		 */
		add_editor_style( array( 'assets/css/editor-style.css', fotografie_fonts_url() ) );

		/**
		 * Load up our theme update notifier.
		 */
		$update_notifier = get_theme_mod( 'Fotografie_Update_notifier' );

		if ( ! $update_notifier ) {
			require trailingslashit( get_template_directory() ) . 'inc/update-notifier.php';
		}
	}
endif;
add_action( 'after_setup_theme', 'fotografie_setup' );

if ( ! function_exists( 'fotografie_content_width' ) ) :
	/**
	 * Set the content width in pixels, based on the theme's design and stylesheet.
	 *
	 * Priority 0 to make it available to lower priority callbacks.
	 *
	 * @global int $content_width
	 */
	function fotografie_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'fotografie_content_width', 756 );
	}
endif;
add_action( 'after_setup_theme', 'fotografie_content_width', 0 );


if ( ! function_exists( 'fotografie_adjusted_content_width' ) ) :
	/**
	 * Adjust $content_width for front-page.php templates
	 */
	function fotografie_adjusted_content_width() {
		$layout = fotografie_get_theme_layout();

		if ( 'no-sidebar-full-width' === $layout ) {
			$GLOBALS['content_width'] = 1376;

			if ( 'fluid' === get_theme_mod( 'fotografie_layout_type' ) ) {
				$GLOBALS['content_width'] = 1696;
			}
		} elseif ( 'no-sidebar-full-content-width' === $layout ) {
			$GLOBALS['content_width'] = 1070;
		}
	}
endif;
add_action( 'template_redirect', 'fotografie_adjusted_content_width' );


/**
 * Return early if Custom Logos are not available.
 *
 * @todo Remove after WP 4.7
 */
function fotografie_the_custom_logo() {
	if ( ! function_exists( 'the_custom_logo' ) ) {
		return;
	} else {
		the_custom_logo();
	}
}

/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 *
 */
function fotografie_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-2' ) ) {
		$count++;
	}

	if ( is_active_sidebar( 'sidebar-3' ) ) {
		$count++;
	}

	if ( is_active_sidebar( 'sidebar-4' ) ) {
		$count++;
	}

	if ( is_active_sidebar( 'sidebar-5' ) ) {
		$count++;
	}

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
		case '4':
			$class = 'four';
			break;
	}

	if ( $class ) {
		echo 'class="widget-area footer-widget-area ' . esc_attr( $class ) . '"';
	}
}

if ( ! function_exists( 'fotografie_fonts_url' ) ) :
	/**
	 * Register Google fonts for Fotografie Pro.
	 *
	 * Create your own fotografie_fonts_url() function to override in a child theme.
	 *
	 * @since Fotografie Pro 1.0
	 *
	 * @return string Google fonts URL for the theme.
	 */
	function fotografie_fonts_url() {
		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin,latin-ext';

		$font_values   = array();
		$font_values[] = get_theme_mod( 'fotografie_body_font', 'montserrat' );
		$font_values[] = get_theme_mod( 'fotografie_title_font', 'montserrat' );
		$font_values[] = get_theme_mod( 'fotografie_tagline_font', 'montserrat' );
		$font_values[] = get_theme_mod( 'fotografie_content_title_font', 'montserrat' );
		$font_values[] = get_theme_mod( 'fotografie_content_font', 'montserrat' );
		$font_values[] = get_theme_mod( 'fotografie_headings_font', 'montserrat' );

		$web_fonts = array(
			'allan'             => 'Allan',
			'allerta'           => 'Allerta',
			'amaranth'          => 'Amaranth',
			'amatic-sc'         => 'Amatic SC',
			'bitter'            => 'Bitter',
			'cabin'             => 'Cabin',
			'cantarell'         => 'Cantarell',
			'crimson-text'      => 'Crimson+Text',
			'cuprum'            => 'Cuprum',
			'dancing-script'    => 'Dancing Script',
			'droid-sans'        => 'Droid Sans',
			'droid-serif'       => 'Droid Serif',
			'exo'               => 'Exo',
			'exo-2'             => 'Exo 2',
			'istok-web'         => 'Istok Web',
			'josefin-sans'      => 'Josefin Sans',
			'lato'              => 'Lato',
			'lobster'           => 'Lobster',
			'lora'              => 'Lora',
			'montserrat'        => 'Montserrat',
			'nobile'            => 'Nobile',
			'noto-serif'        => 'Noto Serif',
			'neuton'            => 'Neuton',
			'open-sans'         => 'Open Sans',
			'oswald'            => 'Oswald',
			'patua-one'         => 'Patua One',
			'playfair-display'  => 'Playfair Display',
			'pt-sans'           => 'PT Sans',
			'pt-serif'          => 'PT Serif',
			'rubik'             => 'Rubik',
			'quattrocento-sans' => 'Quattrocento Sans',
			'roboto'            => 'Roboto',
			'roboto-slab'       => 'Roboto Slab',
			'source-sans-pro'   => 'Source Sans Pro',
			'ubuntu'            => 'Ubuntu',
			'varela'            => 'Varela',
			'yanone-kaffeesatz' => 'Yanone Kaffeesatz',
		);

		$font_values = array_unique( $font_values ); // Make the array of fonts unique so that same font is not loaded twice.

		$font_values = array_intersect( $font_values, array_keys( $web_fonts ) ); // Intersect selected fonts and webfonts to only recover fonts that need loading.

		foreach ( $font_values as $font_value ) {
			$fonts[] = $web_fonts[ $font_value ] . ':400,700,900,400italic,700italic,900italic';
		}

		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $fonts ) ),
				'subset' => urlencode( $subsets ),
			), 'https://fonts.googleapis.com/css' );
		}

		return esc_url( $fonts_url );
	}
endif;

/**
 * Enqueue scripts and styles.
 */
function fotografie_scripts() {
	wp_enqueue_style( 'fotografie-fonts', fotografie_fonts_url(), array(), null );

	wp_enqueue_style( 'font-awesome', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/css/font-awesome.css', array(), '4.7.0', 'all' );

	wp_enqueue_style( 'fotografie-style', get_stylesheet_uri() );

	wp_enqueue_script( 'fotografie-skip-link-focus-fix', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/skip-link-focus-fix.min.js', array(), '20170616', true );

	wp_enqueue_script( 'fotografie-navigation', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/navigation.min.js', array(), '20170616', true );

	wp_register_script( 'jquery-match-height', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/jquery.matchHeight.min.js', array( 'jquery' ), '20151215', true );

	wp_enqueue_script( 'fotografie-custom-script', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/custom-scripts.min.js', array( 'jquery', 'jquery-match-height' ), '20170616', true );

	wp_localize_script( 'fotografie-custom-script', 'fotografieScreenReaderText', array(
		'expand'   => esc_html__( 'expand child menu', 'fotografie-pro' ),
		'collapse' => esc_html__( 'collapse child menu', 'fotografie-pro' ),
	) );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	$font_family_css = fotografie_get_font_family_css();

	if ( '' !== $font_family_css ) {
		wp_add_inline_style( 'fotografie-style', $font_family_css );
	}

	//Slider Scripts
	if ( 'disabled' !== get_theme_mod( 'fotografie_slider_option', 'disabled' ) ) {
		wp_enqueue_script( 'jquery-cycle2', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/jquery.cycle/jquery.cycle2.min.js', array( 'jquery' ), '2.1.5', true );

		$transition_effects = array(
			get_theme_mod( 'fotografie_slider_transition_effects', 'fade' ),
		);

		/**
		 * Condition checks for additional slider transition plugins
		 */
		// Scroll Vertical transition plugin addition.
		if ( in_array( 'scrollVert', $transition_effects, true ) ) {
			wp_enqueue_script( 'jquery-cycle2-scrollVert', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/jquery.cycle/jquery.cycle2.scrollVert.min.js', array( 'jquery-cycle2' ), '2.1.5', true );
		}

		// Flip transition plugin addition.
		if ( in_array( 'flipHorz', $transition_effects, true ) || in_array( 'flipVert', $transition_effects, true ) ) {
			wp_enqueue_script( 'jquery-cycle2-flip', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/jquery.cycle/jquery.cycle2.flip.min.js', array( 'jquery-cycle2' ), '2.1.5', true );
		}

		// Shuffle transition plugin addition.
		if ( in_array( 'tileSlide', $transition_effects, true ) || in_array( 'tileBlind', $transition_effects, true ) ) {
			wp_enqueue_script( 'jquery-cycle2-tile', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/jquery.cycle/jquery.cycle2.tile.min.js', array( 'jquery-cycle2' ), '2.1.5', true );
		}

		// Shuffle transition plugin addition.
		if ( in_array( 'shuffle', $transition_effects, true ) ) {
			wp_enqueue_script( 'jquery-cycle2-shuffle', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/jquery.cycle/jquery.cycle2.shuffle.min.js', array( 'jquery-cycle2' ), '2.1.5', true );
		}
	}

	// Enqueue fitvid if JetPack is not installed.
	if ( ! class_exists( 'Jetpack' ) ) {
		wp_enqueue_script( 'jquery-fitvids', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/fitvids.min.js', array( 'jquery' ), '1.1', true );
	}
}
add_action( 'wp_enqueue_scripts', 'fotografie_scripts' );

/**
 * Checks if there are options already present from Fotografie free version and adds it to the Fotografie Pro theme options
 *
 * @since Fotografie Pro 1.0
 * @hook after_theme_switch
 */
function fotografie_setup_options( $old_theme_name ) {
	if ( $old_theme_name ) {
		$old_theme_slug = sanitize_title( $old_theme_name );

		$free_version_slug = 'fotografie';
		$pro_version_slug  = 'fotografie-pro';

		$free_options = get_option( 'theme_mods_' . $old_theme_slug );

		// Perform action only if options of free version exists and theme is being switched from free version
		if ( $free_version_slug === $old_theme_slug && $free_options && '1' !== get_theme_mod( 'free_pro_migration' ) ) {
			$new_options = wp_parse_args( get_theme_mods(), $free_options );

			if ( update_option( 'theme_mods_' . $pro_version_slug, $free_options ) ) {
				// Set Migration Parameter to true so that this script does not run multiple times.
				set_theme_mod( 'free_pro_migration', '1' );
			}
		}
	}
}
add_action( 'after_switch_theme', 'fotografie_setup_options', 100 );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Include Breadcrumb
 */
require get_parent_theme_file_path( '/inc/breadcrumb.php' );

/**
 * Include Slider
 */
require get_parent_theme_file_path( '/inc/featured-slider.php' );

/**
 * Include Widgets
 */
require get_parent_theme_file_path( '/inc/widgets/widgets.php' );

/**
 * Include WooCommerce Support
 */
require get_parent_theme_file_path( '/inc/woocommerce.php' );

/**
 * Include Metabox
 */
require get_parent_theme_file_path( '/inc/metabox/metabox.php' );
