<?php
/**
 * Fotografie Pro Customizer functionality
 *
 * @package WordPress
 * @subpackage Twenty_Sixteen
 * @since Fotografie Pro 1.6
 */

if ( ! function_exists( 'fotografie_custom_header_and_background' ) ) :
/**
 * Sets up the WordPress core custom header and custom background features.
 *
 * @since Fotografie Pro 1.6
 *
 * @see fotografie_header_style()
 */
function fotografie_custom_header_and_background() {
	$color_scheme             	= fotografie_get_color_scheme();
	$default_background_color 	= trim( $color_scheme[0], '#' );
	$header_text_color      	= trim( $color_scheme[4], '#' ); /* Secondary Text Color */

	/**
	 * Filter the arguments used when adding 'custom-background' support in Fotografie Pro.
	 *
	 * @since Fotografie Pro 1.6
	 *
	 * @param array $args {
	 *     An array of custom-background support arguments.
	 *
	 *     @type string $default-color Default color of the background.
	 * }
	 */
	add_theme_support( 'custom-background', apply_filters( 'fotografie_custom_background_args', array(
		'default-color' => $default_background_color,
	) ) );

	/**
	 * Filter the arguments used when adding 'custom-header' support in Fotografie Pro.
	 *
	 * @since Fotografie Pro 1.6
	 *
	 * @param array $args {
	 *     An array of custom-header support arguments.
	 *
	 *     @type string $default-text-color Default color of the header text.
	 *     @type int      $width            Width in pixels of the custom header image. Default 1200.
	 *     @type int      $height           Height in pixels of the custom header image. Default 280.
	 *     @type bool     $flex-height      Whether to allow flexible-height header images. Default true.
	 *     @type callable $wp-head-callback Callback function used to style the header image and text
	 *                                      displayed on the blog.
	 * }
	 */
	add_theme_support( 'custom-header', apply_filters( 'fotografie_custom_header_args', array(
		'default-image'      => get_parent_theme_file_uri( '/assets/images/header-image.jpg' ),
		'default-text-color' => $header_text_color,
		'width'              => 1920,
		'height'             => 689,
		'flex-height'        => true,
		'flex-width'         => true,
		'video'              => true,
		'wp-head-callback'   => 'fotografie_header_style',
	) ) );

	register_default_headers( array(
		'default-image' => array(
			'url'           => '%s/assets/images/header-image.jpg',
			'thumbnail_url' => '%s/assets/images/header-image.jpg',
			'description'   => esc_html__( 'Default Header Image', 'fotografie-pro' ),
		),
	) );
}
endif;
add_action( 'after_setup_theme', 'fotografie_custom_header_and_background' );

/**
 * Adds postMessage support for site title and description for the Customizer.
 *
 * @since Fotografie Pro 1.6
 *
 * @param WP_Customize_Manager $wp_customize The Customizer object.
 */
function fotografie_colors_customize_register( $wp_customize ) {
	$color_scheme = fotografie_get_color_scheme();

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'            => '.site-title a',
			'container_inclusive' => false,
			'render_callback'     => 'forografie_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'            => '.site-description',
			'container_inclusive' => false,
			'render_callback'     => 'forografie_customize_partial_blogdescription',
		) );
	}

	// Add color scheme setting and control.
	$wp_customize->add_setting( 'color_scheme', array(
		'default'           => 'default',
		'sanitize_callback' => 'fotografie_sanitize_color_scheme',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( 'color_scheme', array(
		'label'    => esc_html__( 'Base Color Scheme', 'fotografie-pro' ),
		'section'  => 'colors',
		'type'     => 'select',
		'choices'  => fotografie_get_color_scheme_choices(),
		'priority' => 1,
	) );

	// Add page background color setting and control.
	$wp_customize->add_setting( 'page_background_color', array(
		'default'           => $color_scheme[1],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'page_background_color', array(
		'label'       => esc_html__( 'Page Background Color', 'fotografie-pro' ),
		'section'     => 'colors',
	) ) );

	// Add link color setting and control.
	$wp_customize->add_setting( 'link_color', array(
		'default'           => $color_scheme[2],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
		'label'       => esc_html__( 'Link Color', 'fotografie-pro' ),
		'section'     => 'colors',
	) ) );

	// Add main text color setting and control.
	$wp_customize->add_setting( 'main_text_color', array(
		'default'           => $color_scheme[3],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'main_text_color', array(
		'label'       => esc_html__( 'Main Text Color', 'fotografie-pro' ),
		'section'     => 'colors',
	) ) );

	// Remove the core header textcolor control, as it shares the secondary text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Add secondary text color setting and control.
	$wp_customize->add_setting( 'secondary_text_color', array(
		'default'           => $color_scheme[4],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_text_color', array(
		'label'       => esc_html__( 'Secondary Text Color', 'fotografie-pro' ),
		'section'     => 'colors',
	) ) );

	// Add secondary Background color setting and control.
	$wp_customize->add_setting( 'secondary_background_color', array(
		'default'           => $color_scheme[5],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'         => 'postMessage',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_background_color', array(
		'label'       => esc_html__( 'Secondary Background Color', 'fotografie-pro' ),
		'section'     => 'colors',
	) ) );
}
add_action( 'customize_register', 'fotografie_colors_customize_register', 11 );

/**
 * Render the site title for the selective refresh partial.
 *
 * @since Fotografie Pro 1.6
 * @see fotografie_customize_register()
 *
 * @return void
 */
function fotografie_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since Fotografie Pro 1.6
 * @see fotografie_customize_register()
 *
 * @return void
 */
function fotografie_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Registers color schemes for Fotografie Pro.
 *
 * Can be filtered with {@see 'fotografie_color_schemes'}.
 *
 * The order of colors in a colors array:
 * 1. Main Background Color.
 * 2. Page Background Color.
 * 3. Link Color.
 * 4. Main Text Color.
 * 5. Secondary Text Color.
 *
 * @since Fotografie Pro 1.6
 *
 * @return array An associative array of color scheme options.
 */
function fotografie_get_color_schemes() {
	/**
	 * Filter the color schemes registered for use with Fotografie Pro.
	 *
	 * The default schemes include 'default', 'dark', 'gray', 'red', and 'yellow'.
	 *
	 * @since Fotografie Pro 1.6
	 *
	 * @param array $schemes {
	 *     Associative array of color schemes data.
	 *
	 *     @type array $slug {
	 *         Associative array of information for setting up the color scheme.
	 *
	 *         @type string $label  Color scheme label.
	 *         @type array  $colors HEX codes for default colors prepended with a hash symbol ('#').
	 *                              Colors are defined in the following order: Main background, page
	 *                              background, link, main text, secondary text.
	 *     }
	 * }
	 */
	return apply_filters( 'fotografie_color_schemes', array(
		'default' => array(
			'label'  => esc_html__( 'Default', 'fotografie-pro' ),
			'colors' => array(
				'#f6f6f6', /* Background Color */
				'#ffffff', /* Page Background Color */
				'#000000', /* Link Color */
				'#000000', /* Main Text Color */
				'#ffffff', /* Secondary Text Color */
				'#000000', /* Secondary Background Color */
			),
		),
		'dark' => array(
			'label'  => esc_html__( 'Dark', 'fotografie-pro' ),
			'colors' => array(
				'#222222', /* Background Color */
				'#111111', /* Page Background Color */
				'#ffffff', /* Link Color */
				'#ffffff', /* Main Text Color */
				'#ffffff', /* Secondary Text Color */
				'#000000', /* Secondary Background Color */
			),
		),
		'gray' => array(
			'label'  => esc_html__( 'Gray', 'fotografie-pro' ),
			'colors' => array(
				'#f6f6f6', /* Background Color */
				'#616a73', /* Page Background Color */
				'#c7c7c7', /* Link Color */
				'#f2f2f2', /* Main Text Color */
				'#ffffff', /* Secondary Text Color */
				'#4d545c', /* Secondary Background Color */
			),
		),
		'red' => array(
			'label'  => esc_html__( 'Red', 'fotografie-pro' ),
			'colors' => array(
				'#f6f6f6', /* Background Color */
				'#ff675f', /* Page Background Color */
				'#640c1f', /* Link Color */
				'#402b30', /* Main Text Color */
				'#402b30', /* Secondary Text Color */
				'#ff675f', /* Secondary Background Color */
			),
		),
		'yellow' => array(
			'label'  => esc_html__( 'Yellow', 'fotografie-pro' ),
			'colors' => array(
				'#3b3721', /* Background Color */
				'#ffef8e', /* Page Background Color */
				'#774e24', /* Link Color */
				'#3b3721', /* Main Text Color */
				'#3b3721', /* Secondary Text Color */
				'#ffef8e', /* Secondary Background Color */
			),
		),
	) );
}

if ( ! function_exists( 'fotografie_get_color_scheme' ) ) :
/**
 * Retrieves the current Fotografie Pro color scheme.
 *
 * Create your own fotografie_get_color_scheme() function to override in a child theme.
 *
 * @since Fotografie Pro 1.6
 *
 * @return array An associative array of either the current or default color scheme HEX values.
 */
function fotografie_get_color_scheme() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );
	$color_schemes       = fotografie_get_color_schemes();

	if ( array_key_exists( $color_scheme_option, $color_schemes ) ) {
		return $color_schemes[ $color_scheme_option ]['colors'];
	}

	return $color_schemes['default']['colors'];
}
endif; // fotografie_get_color_scheme

if ( ! function_exists( 'fotografie_get_color_scheme_choices' ) ) :
/**
 * Retrieves an array of color scheme choices registered for Fotografie Pro.
 *
 * Create your own fotografie_get_color_scheme_choices() function to override
 * in a child theme.
 *
 * @since Fotografie Pro 1.6
 *
 * @return array Array of color schemes.
 */
function fotografie_get_color_scheme_choices() {
	$color_schemes                = fotografie_get_color_schemes();
	$color_scheme_control_options = array();

	foreach ( $color_schemes as $color_scheme => $value ) {
		$color_scheme_control_options[ $color_scheme ] = $value['label'];
	}

	return $color_scheme_control_options;
}
endif; // fotografie_get_color_scheme_choices


if ( ! function_exists( 'fotografie_sanitize_color_scheme' ) ) :
/**
 * Handles sanitization for Fotografie Pro color schemes.
 *
 * Create your own fotografie_sanitize_color_scheme() function to override
 * in a child theme.
 *
 * @since Fotografie Pro 1.6
 *
 * @param string $value Color scheme name value.
 * @return string Color scheme name.
 */
function fotografie_sanitize_color_scheme( $value ) {
	$color_schemes = fotografie_get_color_scheme_choices();

	if ( ! array_key_exists( $value, $color_schemes ) ) {
		return 'default';
	}

	return $value;
}
endif; // fotografie_sanitize_color_scheme

/**
 * Enqueues front-end CSS for color scheme.
 *
 * @since Fotografie Pro 1.6
 *
 * @see wp_add_inline_style()
 */
function fotografie_color_scheme_css() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );

	// Don't do anything if the default color scheme is selected.
	if ( 'default' === $color_scheme_option ) {
		return;
	}

	$color_scheme = fotografie_get_color_scheme();

	// Convert main text hex color to rgba.
	$color_textcolor_rgb = fotografie_hex2rgb( $color_scheme[3] );

	// If the rgba values are empty return early.
	if ( empty( $color_textcolor_rgb ) ) {
		return;
	}

	// Convert link color hex color to rgba.
	$color_linkcolor_rgb = fotografie_hex2rgb( $color_scheme[2] );

	// Convert secondary text hex color to rgba.
	$color_secondarycolor_rgb = fotografie_hex2rgb( $color_scheme[4] );

	// Convert secondary background hex color to rgba.
	$color_secondarybackground_rgb = fotografie_hex2rgb( $color_scheme[5] );

	// If we get this far, we have a custom color scheme.
	$colors = array(
		'background_color'      				=> $color_scheme[0],
		'page_background_color' 				=> $color_scheme[1],
		'link_color'            				=> $color_scheme[2],
		'link_seven_color'						=> vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.07)', $color_linkcolor_rgb ),
		'main_text_color'       				=> $color_scheme[3],
		'main_text_seventy_color'       		=> vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.70)', $color_textcolor_rgb ),
		'main_text_eight_color'       			=> vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.08)', $color_textcolor_rgb ),
		'main_text_five_color'              	=> vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.05)', $color_textcolor_rgb ),
		'secondary_text_color'  				=> $color_scheme[4],
		'secondary_text_seventy_color'			=> vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.70)', $color_secondarycolor_rgb ),
		'secondary_text_twentyfive_color'		=> vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.25)', $color_secondarycolor_rgb ),
		'secondary_text_five_color'         	=> vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.05)', $color_secondarycolor_rgb ),
		'secondary_background_color'  			=> $color_scheme[5],
		'secondary_background_seventy_color'	=> vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.70)', $color_secondarybackground_rgb ),
		'secondary_background_two_color'		=> vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.02)', $color_secondarybackground_rgb ),
		'border_color'          				=> vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.25)', $color_textcolor_rgb ),
	);

	$color_scheme_css = fotografie_get_color_scheme_css( $colors );

	wp_add_inline_style( 'fotografie-style', $color_scheme_css );
}
add_action( 'wp_enqueue_scripts', 'fotografie_color_scheme_css' );

/**
 * Binds the JS listener to make Customizer color_scheme control.
 *
 * Passes color scheme data as colorScheme global.
 *
 * @since Fotografie Pro 1.6
 */
function fotografie_customize_control_js() {
	wp_enqueue_script( 'color-scheme-control', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/color-scheme-control.min.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), '20160816', true );
	wp_localize_script( 'color-scheme-control', 'colorScheme', fotografie_get_color_schemes() );
}
add_action( 'customize_controls_enqueue_scripts', 'fotografie_customize_control_js' );

/**
 * Returns CSS for the color schemes.
 *
 * @since Fotografie Pro 1.6
 *
 * @param array $colors Color scheme colors.
 * @return string Color scheme CSS.
 */
function fotografie_get_color_scheme_css( $colors ) {
	$colors = wp_parse_args( $colors, array(
		'background_color'      				=> '',
		'page_background_color' 				=> '',
		'link_color'            				=> '',
		'link_seven_color'						=> '',
		'main_text_color'       				=> '',
		'main_text_seventy_color'				=> '',
		'main_text_eight_color'					=> '',
		'main_text_five_color'					=> '',
		'secondary_text_color'  				=> '',
		'secondary_text_seventy_color'  		=> '',
		'secondary_text_twentyfive_color'  		=> '',
		'secondary_text_five_color'				=> '',
		'secondary_background_color'			=> '',
		'secondary_background_seventy_color'	=> '',
		'secondary_background_two_color'		=> '',
		'border_color'							=> '',
	) );

	return <<<CSS
	/* Color Scheme */

	/* Background Color */
	body {
		background-color: {$colors['background_color']};
	}

	/* Page Background Color */
	.site-inner,
	.blog-section-headline .page-title,
	.search-wrapper,
	select option {
		background-color: {$colors['page_background_color']};
	}

	.search-wrapper:before {
		border-bottom-color: {$colors['page_background_color']};
	}

	/* Link Color */
	a,
	.portfolio-wrapper a,
	.post-archive .entry-title a,
	.hero-content-wrapper .entry-title a,
	.more-link,
	.post-archive .entry-meta a:hover,
	.post-archive .entry-meta a:focus,
	.comment-metadata a:hover,
	.comment-metadata a:focus,
	.woocommerce .woocommerce-breadcrumb.entry-breadcrumbs a {
		color: {$colors['link_color']};
	}

	/* Text Color */
	input[type="text"]:focus,
	input[type="email"]:focus,
	input[type="url"]:focus,
	input[type="password"]:focus,
	input[type="search"]:focus,
	input[type="number"]:focus,
	input[type="tel"]:focus,
	input[type="range"]:focus,
	input[type="date"]:focus,
	input[type="month"]:focus,
	input[type="week"]:focus,
	input[type="time"]:focus,
	input[type="datetime"]:focus,
	input[type="datetime-local"]:focus,
	input[type="color"]:focus,
	textarea:focus,
	select:focus,
	.comment-author .fn {
		color: {$colors['main_text_color']};
	}

	/* Text Color Seventy */
	body,
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	input[type="number"],
	input[type="tel"],
	input[type="range"],
	input[type="date"],
	input[type="month"],
	input[type="week"],
	input[type="time"],
	input[type="datetime"],
	input[type="datetime-local"],
	input[type="color"],
	textarea,
	select,
	.search-wrapper .search-field,
	a:hover,
	a:focus,
	a:active,
	.portfolio-wrapper a:hover,
	.portfolio-wrapper a:focus,
	.post-archive .entry-title a:hover,
	.post-archive .entry-title a:focus,
	.hero-content-wrapper .entry-title a:hover,
	.hero-content-wrapper .entry-title a:focus,
	.more-link:hover,
	.more-link:focus,
	.post-archive .entry-meta,
	.post-archive .entry-meta a,
	.comment-metadata a,
	.woocommerce .woocommerce-breadcrumb.entry-breadcrumbs a:hover,
	.woocommerce .woocommerce-breadcrumb.entry-breadcrumbs a:focus,
	.woocommerce .woocommerce-breadcrumb.entry-breadcrumbs {
	    color: {$colors['main_text_seventy_color']};
	}

	/* Text Color Eight */
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	input[type="number"],
	input[type="tel"],
	input[type="range"],
	input[type="date"],
	input[type="month"],
	input[type="week"],
	input[type="time"],
	input[type="datetime"],
	input[type="datetime-local"],
	input[type="color"],
	textarea,
	select,
	.search-wrapper .search-field,
	pre {
	    background-color: {$colors['main_text_eight_color']};
	}

	.breadcrumb-area {
	    border-color: {$colors['main_text_five_color']};
	}

	.hero-content-wrapper,
	.portfolio-wrapper .hentry:nth-child(2n),
	.post-archive .hentry:nth-child(2n) .entry-container,
	.search-results .post-archive .product:nth-child(2n) .entry-container {
	    background-color: {$colors['main_text_five_color']};
	}

	/* Secondary Text Color */
	.site-title a,
	.main-navigation a:hover,
	.main-navigation a:focus,
	.main-navigation ul.menu li:hover > a,
	.main-navigation ul.menu li.focus > a,
	.main-navigation ul.menu li:active > a,
	.search-toggle,
	.footer-widget-area a,
	.post-archive .sticky .entry-title a,
	.post-archive .sticky .more-link,
	.post-archive .sticky .entry-meta a:hover,
	.post-archive .sticky .entry-meta a:focus,
	.site-info a:hover,
	.site-info a:focus,
	.site-footer input[type="text"]:focus,
	.site-footer input[type="email"]:focus,
	.site-footer input[type="url"]:focus,
	.site-footer input[type="password"]:focus,
	.site-footer input[type="search"]:focus,
	.site-footer input[type="number"]:focus,
	.site-footer input[type="tel"]:focus,
	.site-footer input[type="range"]:focus,
	.site-footer input[type="date"]:focus,
	.site-footer input[type="month"]:focus,
	.site-footer input[type="week"]:focus,
	.site-footer input[type="time"]:focus,
	.site-footer input[type="datetime"]:focus,
	.site-footer input[type="datetime-local"]:focus,
	.site-footer input[type="color"]:focus,
	.site-footer textarea:focus,
	.button,
	button,
	input[type="button"],
	input[type="reset"],
	input[type="submit"],
	.comment-navigation a,
	.posts-navigation a,
	.site-main #infinite-handle span button,
	#scrollup,
	#feature-slider .more-link:hover span,
	#feature-slider .more-link:focus span,
	#feature-slider .cycle-prev:hover,
	#feature-slider .cycle-prev:focus,
	#feature-slider .cycle-next:hover,
	#feature-slider .cycle-next:focus {
		color: {$colors['secondary_text_color']};
	}

	.site-title a:hover,
	.site-title a:focus,
	.site-description,
	.search-toggle:hover,
	.search-toggle:focus,
	.main-navigation a,
	.site-footer,
	.post-archive .hentry.sticky .entry-container,
	.site-info a,
	.footer-widget-area.widget-area .widget-title,
	.footer-widget-area a:hover,
	.footer-widget-area a:focus,
	.post-archive .sticky .entry-title a:hover,
	.post-archive .sticky .entry-title a:focus,
	.post-archive .sticky .more-link:hover,
	.post-archive .sticky .more-link:focus,
	.post-archive .sticky .entry-meta,
	.post-archive .sticky .entry-meta a,
	.site-footer input[type="text"],
	.site-footer input[type="email"],
	.site-footer input[type="url"],
	.site-footer input[type="password"],
	.site-footer input[type="search"],
	.site-footer input[type="number"],
	.site-footer input[type="tel"],
	.site-footer input[type="range"],
	.site-footer input[type="date"],
	.site-footer input[type="month"],
	.site-footer input[type="week"],
	.site-footer input[type="time"],
	.site-footer input[type="datetime"],
	.site-footer input[type="datetime-local"],
	.site-footer input[type="color"],
	.site-footer textarea,
	.site-footer select {
	    color: {$colors['secondary_text_seventy_color']};
	}

	#scrollup,
	#scrollup:hover,
	#scrollup:focus,
	.site-header-menu,
	.social-navigation a {
	    border-color: {$colors['secondary_text_twentyfive_color']};
	}

	.site-footer input[type="text"],
	.site-footer input[type="email"],
	.site-footer input[type="url"],
	.site-footer input[type="password"],
	.site-footer input[type="search"],
	.site-footer input[type="number"],
	.site-footer input[type="tel"],
	.site-footer input[type="range"],
	.site-footer input[type="date"],
	.site-footer input[type="month"],
	.site-footer input[type="week"],
	.site-footer input[type="time"],
	.site-footer input[type="datetime"],
	.site-footer input[type="datetime-local"],
	.site-footer input[type="color"],
	.site-footer textarea,
	.site-footer select {
		background-color: {$colors['secondary_text_twentyfive_color']};
	}

	.site-footer select {
	    border-color: {$colors['secondary_text_five_color']};
	}

	.main-navigation ul ul a:hover,
	.main-navigation ul ul > li.focus > a {
	    background-color: {$colors['secondary_text_five_color']};
	}

	/* Secondary Background Color */
	#masthead,
	.site-footer,
	.post-archive .hentry.sticky .entry-container,
	.button,
	button,
	input[type="button"],
	input[type="reset"],
	input[type="submit"],
	.comment-navigation a,
	.posts-navigation a,
	.site-main #infinite-handle span button,
	#scrollup,
	#feature-slider .more-link:hover span,
	#feature-slider .more-link:focus span,
	#feature-slider .cycle-prev:hover,
	#feature-slider .cycle-prev:focus,
	#feature-slider .cycle-next:hover,
	#feature-slider .cycle-next:focus,
	.site-footer select option {
	    background-color: {$colors['secondary_background_color']};
	}

	#feature-slider .more-link:hover span,
	#feature-slider .more-link:focus span,
	#feature-slider .cycle-prev:hover,
	#feature-slider .cycle-prev:focus,
	#feature-slider .cycle-next:hover,
	#feature-slider .cycle-next:focus {
		border-color: {$colors['secondary_background_color']};
	}

	.button:hover,
	.button:focus,
	button:hover,
	button:active,
	button:focus,
	input[type="button"]:hover,
	input[type="button"]:active,
	input[type="button"]:focus,
	input[type="reset"]:hover,
	input[type="reset"]:active,
	input[type="reset"]:focus,
	input[type="submit"]:hover,
	input[type="submit"]:active,
	input[type="submit"]:focus,
	.comment-navigation a:hover,
	.comment-navigation a:focus,
	.posts-navigation a:hover,
	.posts-navigation a:focus,
	.post-navigation a:hover,
	.post-navigation a:focus,
	.site-main #infinite-handle span button:hover,
	.site-main #infinite-handle span button:focus,
	#scrollup:hover,
	#scrollup:focus {
	    background: {$colors['secondary_background_seventy_color']};
	}

	/* Border Color */
	select,
	.page-title-wrapper:before,
	table,
	table caption {
	    border-color: {$colors['border_color']};
	}

	hr {
    	background-color: {$colors['border_color']};
	}
CSS;
}


/**
 * Outputs an Underscore template for generating CSS for the color scheme.
 *
 * The template generates the css dynamically for instant display in the
 * Customizer preview.
 *
 * @since Fotografie Pro 1.6
 */
function fotografie_color_scheme_css_template() {
	$colors = array(
		'background_color'      				=> '{{ data.background_color }}',
		'page_background_color' 				=> '{{ data.page_background_color }}',
		'link_color'            				=> '{{ data.link_color }}',
		'link_seven_color'            			=> '{{ data.link_seven_color }}',
		'main_text_color'       				=> '{{ data.main_text_color }}',
		'main_text_seventy_color'				=> '{{ data.main_text_seventy_color }}',
		'main_text_eight_color'					=> '{{ data.main_text_eight_color }}',
		'main_text_five_color'					=> '{{ data.main_text_five_color }}',
		'secondary_text_color'  				=> '{{ data.secondary_text_color }}',
		'secondary_text_seventy_color'			=> '{{ data.secondary_text_seventy_color }}',
		'secondary_text_twentyfive_color'		=> '{{ data.secondary_text_twentyfive_color }}',
		'secondary_text_five_color'				=> '{{ data.secondary_text_five_color }}',
		'secondary_background_color'			=> '{{ data.secondary_background_color }}',
		'secondary_background_seventy_color'	=> '{{ data.secondary_background_seventy_color }}',
		'secondary_background_two_color'		=> '{{ data.secondary_background_two_color }}',
		'border_color'							=> '{{ data.border_color }}',
	);
	?>
	<script type="text/html" id="tmpl-fotografie-color-scheme">
		<?php echo fotografie_get_color_scheme_css( $colors ); ?>
	</script>
	<?php
}
add_action( 'customize_controls_print_footer_scripts', 'fotografie_color_scheme_css_template' );

/**
 * Enqueues front-end CSS for the page background color.
 *
 * @since Fotografie Pro 1.6
 *
 * @see wp_add_inline_style()
 */
function fotografie_page_background_color_css() {
	$color_scheme          = fotografie_get_color_scheme();
	$default_color         = $color_scheme[1];
	$page_background_color = get_theme_mod( 'page_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $page_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Custom Page Background Color */
		.site-inner,
		.blog-section-headline .page-title,
		.search-wrapper,
		select option {
			background-color: %1$s;
		}
		.search-wrapper:before {
			border-bottom-color: %1$s;
		}
	';

	wp_add_inline_style( 'fotografie-style', sprintf( $css, $page_background_color ) );
}
add_action( 'wp_enqueue_scripts', 'fotografie_page_background_color_css', 11 );

/**
 * Enqueues front-end CSS for the link color.
 *
 * @since Fotografie Pro 1.6
 *
 * @see wp_add_inline_style()
 */
function fotografie_link_color_css() {
	$color_scheme    = fotografie_get_color_scheme();
	$default_color   = $color_scheme[2];
	$link_color = get_theme_mod( 'link_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $link_color === $default_color ) {
		return;
	}

	// Convert link color hex color to rgba.
	$link_color_rgb = fotografie_hex2rgb( $link_color );

	// If the rgba values are empty return early.
	if ( empty( $link_color_rgb ) ) {
		return;
	}

	$link_seven_color		= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.07)', $link_color_rgb );

	$css = '
		/* Custom Link Color */
		a,
		.portfolio-wrapper a,
		.post-archive .entry-title a,
		.hero-content-wrapper .entry-title a,
		.more-link,
		.post-archive .entry-meta a:hover,
		.post-archive .entry-meta a:focus,
		.comment-metadata a:hover,
		.comment-metadata a:focus,
		.woocommerce .woocommerce-breadcrumb.entry-breadcrumbs a {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'fotografie-style', sprintf( $css, $link_color, $link_seven_color ) );
}
add_action( 'wp_enqueue_scripts', 'fotografie_link_color_css', 11 );

/**
 * Enqueues front-end CSS for the main text color.
 *
 * @since Fotografie Pro 1.6
 *
 * @see wp_add_inline_style()
 */
function fotografie_main_text_color_css() {
	$color_scheme    = fotografie_get_color_scheme();
	$default_color   = $color_scheme[3];
	$main_text_color = get_theme_mod( 'main_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $main_text_color === $default_color ) {
		return;
	}

	// Convert main text hex color to rgba.
	$main_text_color_rgb = fotografie_hex2rgb( $main_text_color );

	// If the rgba values are empty return early.
	if ( empty( $main_text_color_rgb ) ) {
		return;
	}

	$main_text_seventy_color	= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.70)', $main_text_color_rgb );
	$main_text_eight_color		= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.08)', $main_text_color_rgb );
	$main_text_five_color		= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.05)', $main_text_color_rgb );
	$border_color				= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.25)', $main_text_color_rgb );

	$css = '
		/* Custom Main Text Color */
		input[type="text"]:focus,
		input[type="email"]:focus,
		input[type="url"]:focus,
		input[type="password"]:focus,
		input[type="search"]:focus,
		input[type="number"]:focus,
		input[type="tel"]:focus,
		input[type="range"]:focus,
		input[type="date"]:focus,
		input[type="month"]:focus,
		input[type="week"]:focus,
		input[type="time"]:focus,
		input[type="datetime"]:focus,
		input[type="datetime-local"]:focus,
		input[type="color"]:focus,
		textarea:focus,
		select:focus,
		.comment-author .fn {
			color: %1$s
		}

		/* Text Color Seventy */
		body,
		input[type="text"],
		input[type="email"],
		input[type="url"],
		input[type="password"],
		input[type="search"],
		input[type="number"],
		input[type="tel"],
		input[type="range"],
		input[type="date"],
		input[type="month"],
		input[type="week"],
		input[type="time"],
		input[type="datetime"],
		input[type="datetime-local"],
		input[type="color"],
		textarea,
		select,
		.search-wrapper .search-field,
		a:hover,
		a:focus,
		a:active,
		.portfolio-wrapper a:hover,
		.portfolio-wrapper a:focus,
		.post-archive .entry-title a:hover,
		.post-archive .entry-title a:focus,
		.hero-content-wrapper .entry-title a:hover,
		.hero-content-wrapper .entry-title a:focus,
		.more-link:hover,
		.more-link:focus,
		.post-archive .entry-meta,
		.post-archive .entry-meta a,
		.comment-metadata a,
		.woocommerce .woocommerce-breadcrumb.entry-breadcrumbs a:hover,
		.woocommerce .woocommerce-breadcrumb.entry-breadcrumbs a:focus,
		.woocommerce .woocommerce-breadcrumb.entry-breadcrumbs {
		    color: %2$s;
		}

		/* Text Color Eight */
		input[type="text"],
		input[type="email"],
		input[type="url"],
		input[type="password"],
		input[type="search"],
		input[type="number"],
		input[type="tel"],
		input[type="range"],
		input[type="date"],
		input[type="month"],
		input[type="week"],
		input[type="time"],
		input[type="datetime"],
		input[type="datetime-local"],
		input[type="color"],
		textarea,
		select,
		.search-wrapper .search-field,
		pre {
		    background-color: %3$s;
		}

		/* Text Color Five */
		.breadcrumb-area {
			border-color: %4$s;
		}

		.hero-content-wrapper,
		.portfolio-wrapper .hentry:nth-child(2n),
		.post-archive .hentry:nth-child(2n) .entry-container,
		.search-results .post-archive .product:nth-child(2n) .entry-container {
			background-color: %4$s;
		}

		/* Border Color */
		select,
		.page-title-wrapper:before,
		table,
		table caption {
		    border-color: %5$s;
		}

		hr {
		    background-color: %5$s;
		}
	';

	wp_add_inline_style( 'fotografie-style', sprintf( $css, $main_text_color, $main_text_seventy_color, $main_text_eight_color, $main_text_five_color, $border_color ) );
}
add_action( 'wp_enqueue_scripts', 'fotografie_main_text_color_css', 11 );

/**
 * Enqueues front-end CSS for the secondary text color.
 *
 * @since Fotografie Pro 1.6
 *
 * @see wp_add_inline_style()
 */
function fotografie_secondary_text_color_css() {
	$color_scheme    = fotografie_get_color_scheme();
	$default_color   = $color_scheme[4];
	$secondary_text_color = get_theme_mod( 'secondary_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_text_color === $default_color ) {
		return;
	}

	// Convert main text hex color to rgba.
	$secondary_text_color_rgb = fotografie_hex2rgb( $secondary_text_color );

	// If the rgba values are empty return early.
	if ( empty( $secondary_text_color_rgb ) ) {
		return;
	}

	$secondary_text_seventy_color		= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.70)', $secondary_text_color_rgb );
	$secondary_text_twentyfive_color	= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.25)', $secondary_text_color_rgb );
	$secondary_text_five_color			= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.05)', $secondary_text_color_rgb );

	$css = '
		/* Secondary Text Color */
		.site-title a,
		.main-navigation a:hover,
		.main-navigation a:focus,
		.main-navigation ul.menu li:hover > a,
		.main-navigation ul.menu li.focus > a,
		.main-navigation ul.menu li:active > a,
		.search-toggle,
		.footer-widget-area a,
		.post-archive .sticky .entry-title a,
		.post-archive .sticky .more-link,
		.post-archive .sticky .entry-meta a:hover,
		.post-archive .sticky .entry-meta a:focus,
		.site-info a:hover,
		.site-info a:focus,
		.site-footer input[type="text"]:focus,
		.site-footer input[type="email"]:focus,
		.site-footer input[type="url"]:focus,
		.site-footer input[type="password"]:focus,
		.site-footer input[type="search"]:focus,
		.site-footer input[type="number"]:focus,
		.site-footer input[type="tel"]:focus,
		.site-footer input[type="range"]:focus,
		.site-footer input[type="date"]:focus,
		.site-footer input[type="month"]:focus,
		.site-footer input[type="week"]:focus,
		.site-footer input[type="time"]:focus,
		.site-footer input[type="datetime"]:focus,
		.site-footer input[type="datetime-local"]:focus,
		.site-footer input[type="color"]:focus,
		.site-footer textarea:focus,
		.button,
		button,
		input[type="button"],
		input[type="reset"],
		input[type="submit"],
		.comment-navigation a,
		.posts-navigation a,
		.site-main #infinite-handle span button,
		#scrollup,
		#feature-slider .more-link:hover span,
		#feature-slider .more-link:focus span,
		#feature-slider .cycle-prev:hover,
		#feature-slider .cycle-prev:focus,
		#feature-slider .cycle-next:hover,
		#feature-slider .cycle-next:focus {
		    color: %1$s;
		}

		/* Secondary Text Seventy Color */
		.site-title a:hover,
		.site-title a:focus,
		.site-description,
		.search-toggle:hover,
		.search-toggle:focus,
		.main-navigation a,
		.site-footer,
		.post-archive .hentry.sticky .entry-container,
		.site-info a,
		.footer-widget-area.widget-area .widget-title,
		.footer-widget-area a:hover,
		.footer-widget-area a:focus,
		.post-archive .sticky .entry-title a:hover,
		.post-archive .sticky .entry-title a:focus,
		.post-archive .sticky .more-link:hover,
		.post-archive .sticky .more-link:focus,
		.post-archive .sticky .entry-meta,
		.post-archive .sticky .entry-meta a,
		.site-footer input[type="text"],
		.site-footer input[type="email"],
		.site-footer input[type="url"],
		.site-footer input[type="password"],
		.site-footer input[type="search"],
		.site-footer input[type="number"],
		.site-footer input[type="tel"],
		.site-footer input[type="range"],
		.site-footer input[type="date"],
		.site-footer input[type="month"],
		.site-footer input[type="week"],
		.site-footer input[type="time"],
		.site-footer input[type="datetime"],
		.site-footer input[type="datetime-local"],
		.site-footer input[type="color"],
		.site-footer textarea,
		.site-footer select {
		    color: %2$s;
		}

		/* Secondary Text Twentyfive Color */
		#scrollup,
		#scrollup:hover,
		#scrollup:focus,
		.site-header-menu,
		.social-navigation a {
		    border-color: %3$s;
		}

		.site-footer input[type="text"],
		.site-footer input[type="email"],
		.site-footer input[type="url"],
		.site-footer input[type="password"],
		.site-footer input[type="search"],
		.site-footer input[type="number"],
		.site-footer input[type="tel"],
		.site-footer input[type="range"],
		.site-footer input[type="date"],
		.site-footer input[type="month"],
		.site-footer input[type="week"],
		.site-footer input[type="time"],
		.site-footer input[type="datetime"],
		.site-footer input[type="datetime-local"],
		.site-footer input[type="color"],
		.site-footer textarea,
		.site-footer select {
			background-color: %3$s;
		}

		/* Secondary Text Five Color */
		.site-footer select {
		    border-color: %4$s;
		}

		.main-navigation ul ul a:hover,
		.main-navigation ul ul > li.focus > a {
		    background-color: %4$s;
		}
	';

	wp_add_inline_style( 'fotografie-style', sprintf( $css, $secondary_text_color, $secondary_text_seventy_color, $secondary_text_twentyfive_color, $secondary_text_five_color ) );
}
add_action( 'wp_enqueue_scripts', 'fotografie_secondary_text_color_css', 11 );

/**
 * Enqueues front-end CSS for the secondary background color.
 *
 * @since Fotografie Pro 1.6
 *
 * @see wp_add_inline_style()
 */
function fotografie_secondary_background_color_css() {
	$color_scheme    			= fotografie_get_color_scheme();
	$default_color   			= $color_scheme[5];
	$secondary_background_color = get_theme_mod( 'secondary_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_background_color === $default_color ) {
		return;
	}

	// Convert main text hex color to rgba.
	$secondary_background_color_rgb = fotografie_hex2rgb( $secondary_background_color );

	// If the rgba values are empty return early.
	if ( empty( $secondary_background_color_rgb ) ) {
		return;
	}

	$secondary_background_seventy_color	= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.07)', $secondary_background_color_rgb );
	$secondary_background_two_color		= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.02)', $secondary_background_color_rgb );

	$css = '
		/* Secondary Background Color */
		#masthead,
		.site-footer,
		.post-archive .hentry.sticky .entry-container,
		.button,
		button,
		input[type="button"],
		input[type="reset"],
		input[type="submit"],
		.comment-navigation a,
		.posts-navigation a,
		.site-main #infinite-handle span button,
		#scrollup,
		#feature-slider .more-link:hover span,
		#feature-slider .more-link:focus span,
		#feature-slider .cycle-prev:hover,
		#feature-slider .cycle-prev:focus,
		#feature-slider .cycle-next:hover,
		#feature-slider .cycle-next:focus,
		.site-footer select option {
		    background-color: %1$s;
		}

		#feature-slider .more-link:hover span,
		#feature-slider .more-link:focus span,
		#feature-slider .cycle-prev:hover,
		#feature-slider .cycle-prev:focus,
		#feature-slider .cycle-next:hover,
		#feature-slider .cycle-next:focus {
			border-color: %1$s;
		}

		/* Secondary Background Seven Color */
		.button:hover,
		.button:focus,
		button:hover,
		button:active,
		button:focus,
		input[type="button"]:hover,
		input[type="button"]:active,
		input[type="button"]:focus,
		input[type="reset"]:hover,
		input[type="reset"]:active,
		input[type="reset"]:focus,
		input[type="submit"]:hover,
		input[type="submit"]:active,
		input[type="submit"]:focus,
		.comment-navigation a:hover,
		.comment-navigation a:focus,
		.posts-navigation a:hover,
		.posts-navigation a:focus,
		.post-navigation a:hover,
		.post-navigation a:focus,
		.site-main #infinite-handle span button:hover,
		.site-main #infinite-handle span button:focus,
		#scrollup:hover,
		#scrollup:focus {
		    background: %2$s;
		}
	';

	wp_add_inline_style( 'fotografie-style', sprintf( $css, $secondary_background_color, $secondary_background_seventy_color, $secondary_background_two_color ) );
}
add_action( 'wp_enqueue_scripts', 'fotografie_secondary_background_color_css', 11 );

/**
 * Converts a HEX value to RGB.
 *
 * @since Fotografie Pro 1.6
 *
 * @param string $color The original color, in 3- or 6-digit hexadecimal form.
 * @return array Array containing RGB (red, green, and blue) values for the given
 *               HEX code, empty array otherwise.
 */
function fotografie_hex2rgb( $color ) {
	$color = trim( $color, '#' );

	if ( strlen( $color ) === 3 ) {
		$r = hexdec( substr( $color, 0, 1 ).substr( $color, 0, 1 ) );
		$g = hexdec( substr( $color, 1, 1 ).substr( $color, 1, 1 ) );
		$b = hexdec( substr( $color, 2, 1 ).substr( $color, 2, 1 ) );
	} else if ( strlen( $color ) === 6 ) {
		$r = hexdec( substr( $color, 0, 2 ) );
		$g = hexdec( substr( $color, 2, 2 ) );
		$b = hexdec( substr( $color, 4, 2 ) );
	} else {
		return array();
	}

	return array( 'red' => $r, 'green' => $g, 'blue' => $b );
}
